Package 'ggdmcHeaders'

Title: 'C++' Headers for 'ggdmc' Package
Description: A fast 'C++' implementation of the design-based, Diffusion Decision Model (DDM) and the Linear Ballistic Accumulation (LBA) model. It enables the user to optimise the choice response time model by connecting with the Differential Evolution Markov Chain Monte Carlo (DE-MCMC) sampler implemented in the 'ggdmc' package. The package fuses the hierarchical modelling, Bayesian inference, choice response time models and factorial designs, allowing users to build their own design-based models. For more information on the underlying models, see the works by Voss, Rothermund, and Voss (2004) <doi:10.3758/BF03196893>, Ratcliff and McKoon (2008) <doi:10.1162/neco.2008.12-06-420>, and Brown and Heathcote (2008) <doi:10.1016/j.cogpsych.2007.12.002>.
Authors: Yi-Shin Lin [aut, cre]
Maintainer: Yi-Shin Lin <[email protected]>
License: GPL (>= 2)
Version: 0.2.9.1
Built: 2026-06-09 07:08:28 UTC
Source: https://github.com/yxlin/ggdmcheaders

Help Index


'C++' Backend for the 'ggdmc' Ecosystem

Description

The package is a collection of the 'C++' implementation of the choice response time model. It connects the model to the Differential Evolution Markov Chain Monte Carlo (DE-MCMC) sampler implemented in the ggdmc package.

Details

The package supports the hierarchical modelling, Bayesian inference, choice response time models and factorial designs, allowing users to build their own design-based models.

The package serves as the C++ backends for the following packages: ggdmcModel, ggdmcPrior, ggdmcLikelihood, lbaModel, ddModel and ggdmc.

References

  • Voss, A., Rothermund, K., & Voss, J. (2004). Interpreting the parameters of the diffusion model: A empirical validation Memory and Cognition, 32(7), 1206–1220.

  • Ratcliff, R., & McKoon, G. (2008). The diffusion decision model: Theory and data for two-choice decision tasks. Neural Computation, 20(4), 873–922.

  • Brown S., & Heathcote, A. (2008). The simplest complete model of choice response time: Linear ballistic accumulation. Cognitive Psychology, 57(3), 153–178.